@@ -86,7 +86,7 @@
 #define KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOFILEWIDGETS_NO_DEPRECATED
-#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54700
+#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
 #endif
 #ifdef KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54700
+#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54c00
 #  endif
 #endif
 
@@ -145,6 +145,12 @@
 #else
 #  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_70(text)
 #endif
+
+#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_76(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_76(text)
+#endif
 #define KIOFILEWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOFILEWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
